@@ -17,7 +17,7 @@ module WebConsole
     def call(env)
       app_exception = catch :app_exception do
         request = create_regular_or_whiny_request(env)
-        return @app.call(env) unless request.from_whitelited_ip?
+        return call_app(env) unless request.from_whitelisted_ip?
 
         if id = id_for_repl_session_update(request)
           return update_repl_session(id, request)
@@ -25,15 +25,9 @@ module WebConsole
           return change_stack_trace(id, request)
         end
 
-        status, headers, body = @app.call(env)
+        status, headers, body = call_app(env)
 
-        if exception = env['web_console.exception']
-          session = Session.from_exception(exception)
-        elsif binding = env['web_console.binding']
-          session = Session.from_binding(binding)
-        end
-
-        if session && acceptable_content_type?(headers)
+        if session = Session.from(Thread.current) and acceptable_content_type?(headers)
           response = Response.new(body, status, headers)
           template = Template.new(env, session)
 
@@ -49,13 +43,18 @@ module WebConsole
       WebConsole.logger.error("\n#{e.class}: #{e}\n\tfrom #{e.backtrace.join("\n\tfrom ")}")
       raise e
     ensure
+      # Clean up the fiber locals after the session creation. Object#console
+      # uses those to communicate the current binding or exception to the middleware.
+      Thread.current[:__web_console_exception] = nil
+      Thread.current[:__web_console_binding] = nil
+
       raise app_exception if Exception === app_exception
     end
 
     private
 
       def acceptable_content_type?(headers)
-        Mime::Type.parse(headers['Content-Type']).first == Mime::HTML
+        Mime::Type.parse(headers['Content-Type']).first == Mime[:html]
       end
 
       def json_response(opts = {})
