@@ -6,21 +6,18 @@ module WebConsole
     config.web_console.whitelisted_ips = %w( 127.0.0.1 ::1 )
 
     initializer 'web_console.initialize' do
+      require 'web_console/integration'
       require 'web_console/extensions'
 
-      ActiveSupport.on_load(:action_view) do
-        ActionView::Base.send(:include, Helper)
-      end
-
-      ActiveSupport.on_load(:action_controller) do
-        ActionController::Base.send(:include, Helper)
+      if logger = ::Rails.logger
+        WebConsole.logger = logger
       end
     end
 
     initializer 'web_console.development_only' do
       unless (config.web_console.development_only == false) || Rails.env.development?
         abort <<-END.strip_heredoc
-          Web Console is activated in the #{Rails.env} environment, which is
+          Web Console is activated in the #{Rails.env} environment. This is
           usually a mistake. To ensure it's only activated in development
           mode, move it to the development group of your Gemfile:
 
