@@ -5,7 +5,7 @@ module WebConsole
     # The error pages are special, because they are the only pages that
     # currently require multiple bindings. We get those from exceptions.
     def only_on_error_page(*args)
-      yield if @env['web_console.exception'].present?
+      yield if Thread.current[:__web_console_exception].present?
     end
 
     # Render JavaScript inside a script tag and a closure.
@@ -14,6 +14,7 @@ module WebConsole
     # script tag and enclosed in a closure, so you don't have to worry for
     # leaking globals, unless you explicitly want to.
     def render_javascript(template)
+      assign(template: template)
       render(template: template, layout: 'layouts/javascript')
     end
 
@@ -25,6 +26,14 @@ module WebConsole
       render(template: template, layout: 'layouts/inlined_string')
     end
 
+    # Custom ActionView::Base#render wrapper which silences all the log
+    # printings.
+    #
+    # Helps to keep the Rails logs clean during errors.
+    def render(*)
+      WebConsole.logger.silence { super }
+    end
+
     # Override method for ActionView::Helpers::TranslationHelper#t.
     #
     # This method escapes the original return value for JavaScript, since the
